<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+273"/>
        <source>None</source>
        <translation>空</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>英寸</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>英尺</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>英里</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>毫米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>厘米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>千米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>微英寸</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>百万</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>码</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>埃</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>纳米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>微米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>分米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>十米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>百米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>百万公里</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>天体的</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>光年</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>秒差距</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+288"/>
        <source>By Layer</source>
        <translation>按图层</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>按块</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>红色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Green</source>
        <translation>绿色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Blue</source>
        <translation>蓝色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cyan</source>
        <translation>青色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Magenta</source>
        <translation>洋红色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yellow</source>
        <translation>黄色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Orange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>暗红色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>深绿色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>藏青色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>深青绿</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>深洋红</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>暗黄</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>黑色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gray</source>
        <translation>灰色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>浅灰色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>白色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Others...</source>
        <translation>其它...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+45"/>
        <source>Current Layer ID</source>
        <translation>当前图层ID</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>绘图单元</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>线性比例</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>尺寸字体</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+92"/>
        <source>Block</source>
        <translation>块</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+65"/>
        <source>Pixel Unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+82"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translation>缩放比例</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+91"/>
        <location filename="../src/core/RObject.cpp" line="+67"/>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Block ID</source>
        <translation>块ID</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translation>图层</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+102"/>
        <source>Linetype</source>
        <translation>线型</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>线型比例</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>线宽</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>颜色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>描画顺序</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>边界</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>底部</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>上部</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+151"/>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation type="unfinished">处理</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation type="unfinished">受保护的</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>宽度</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>高度</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>简单</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>文本位置</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>文字</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>普通文本</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>字体名称</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>文本高度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>文字角度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>X 比例</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>加粗</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>斜体</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>行距</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-6"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation type="unfinished">名字</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation type="unfinished">隐藏</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation type="unfinished">冻结的</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation type="unfinished">锁定的</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+655"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+186"/>
        <source>Requires selection</source>
        <translation>需要选择</translation>
    </message>
</context>
<context>
    <name>RLayer</name>
    <message>
        <source>Name</source>
        <translation type="vanished">名字</translation>
    </message>
    <message>
        <source>Frozen</source>
        <translation type="vanished">冻结的</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="obsolete">隐藏</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="vanished">锁定的</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">颜色</translation>
    </message>
    <message>
        <source>Linetype</source>
        <translation type="vanished">线型</translation>
    </message>
    <message>
        <source>Lineweight</source>
        <translation type="vanished">线宽</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <source>By Layer</source>
        <translation type="vanished">按图层</translation>
    </message>
    <message>
        <source>By Block</source>
        <translation type="vanished">按块</translation>
    </message>
    <message>
        <source>Continuous</source>
        <translation type="vanished">连续的</translation>
    </message>
    <message>
        <source>Dot</source>
        <translation type="vanished">点</translation>
    </message>
    <message>
        <source>Dot (small)</source>
        <translation type="vanished">点（小）</translation>
    </message>
    <message>
        <source>Dot (large)</source>
        <translation type="vanished">点（大）</translation>
    </message>
    <message>
        <source>Dash</source>
        <translation type="vanished">破折号</translation>
    </message>
    <message>
        <source>Dash (small)</source>
        <translation type="vanished">破折号（小）</translation>
    </message>
    <message>
        <source>Dash (large)</source>
        <translation type="vanished">破折号（大）</translation>
    </message>
    <message>
        <source>Dash Dot</source>
        <translation type="vanished">点划线</translation>
    </message>
    <message>
        <source>Dash Dot (small)</source>
        <translation type="vanished">点划线（小）</translation>
    </message>
    <message>
        <source>Dash Dot (large)</source>
        <translation type="vanished">点划线（大）</translation>
    </message>
    <message>
        <source>Divide</source>
        <translation type="vanished">分割线</translation>
    </message>
    <message>
        <source>Divide (small)</source>
        <translation type="vanished">分割线（小）</translation>
    </message>
    <message>
        <source>Divide (large)</source>
        <translation type="vanished">分割线（大）</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">居中</translation>
    </message>
    <message>
        <source>Center (small)</source>
        <translation type="vanished">居中（小）</translation>
    </message>
    <message>
        <source>Center (large)</source>
        <translation type="vanished">居中（大）</translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="vanished">边界</translation>
    </message>
    <message>
        <source>Border (small)</source>
        <translation type="vanished">边界（小）</translation>
    </message>
    <message>
        <source>Border (large)</source>
        <translation type="vanished">边界（大）</translation>
    </message>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+48"/>
        <source>Name</source>
        <translation type="unfinished">名字</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
        <source>By Layer</source>
        <translation type="unfinished">按图层</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation type="unfinished">按块</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation type="unfinished">连续的</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation type="unfinished">边界</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation type="unfinished">居中</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>点划线</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>虚线</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation type="unfinished">分割线</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation type="unfinished">点</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>隐藏</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>阴影</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO 虚线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO 虚线间隔</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO 双点划线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO 双虚线双点划线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO 虚线三点划线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO 双虚线三点划线</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>热水供应</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>热水</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>煤气管道</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>拍打</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>锯齿</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>轨迹</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>围墙线1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>围墙线2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drainage</source>
        <translation>排水系统</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+35"/>
        <source>By Layer</source>
        <translation>按图层</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>按块</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>默认值</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11mm</translation>
    </message>
</context>
<context>
    <name>RObject</name>
    <message>
        <source>Custom</source>
        <translation type="vanished">自定义</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="obsolete">类型</translation>
    </message>
    <message>
        <source>Handle</source>
        <translation type="vanished">处理</translation>
    </message>
    <message>
        <source>Protected</source>
        <translation type="vanished">受保护的</translation>
    </message>
</context>
</TS>
